pub struct SidebarRoomRow {
avatar: TemplateChild<Avatar>,
display_name_box: TemplateChild<Box>,
room_icon: TemplateChild<Image>,
display_name: TemplateChild<Label>,
notification_count: TemplateChild<Label>,
room: BoundObject<Room>,
}Fields
avatar: TemplateChild<Avatar>display_name_box: TemplateChild<Box>room_icon: TemplateChild<Image>display_name: TemplateChild<Label>notification_count: TemplateChild<Label>room: BoundObject<Room>The room represented by this row.
Implementations
Sourceimpl SidebarRoomRow
impl SidebarRoomRow
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl SidebarRoomRow
impl SidebarRoomRow
Sourcefn update_display_name(&self)
fn update_display_name(&self)
Update the display name of the room according to the current state.
Sourcefn update_highlight(&self)
fn update_highlight(&self)
Update how this row is highlighted according to the current state.
Sourcefn parent_row(&self) -> Option<SidebarRow>
fn parent_row(&self) -> Option<SidebarRow>
The parent SidebarRow of this row.
Sourcefn prepare_drag(
&self,
drag: &DragSource,
x: f64,
y: f64,
) -> Option<ContentProvider>
fn prepare_drag( &self, drag: &DragSource, x: f64, y: f64, ) -> Option<ContentProvider>
Prepare a drag action.
Sourcefn begin_drag(&self)
fn begin_drag(&self)
Begin a drag action.
Sourcefn update_room_icon(&self)
fn update_room_icon(&self)
Update the room icon depending on what type of room it is.
Sourcefn update_accessibility_label(&self)
fn update_accessibility_label(&self)
Update the accessibility label of this row.
Sourcefn accessible_label(&self) -> String
fn accessible_label(&self) -> String
Compute the accessibility label of this row.